<?php
// This file defines how the kiosk index.php file in this directory will
// function.  Certain suggested settings have been made below as an example
// of how this particular kiosk should function.  Please uncomment or change
// settings below to suit your needs. Everything in this file is case
// sensitive, so watch your P's and Q's.  Everything after "//" on a line or
// between /* and */ is treated as a comment and will be ignored.

if (realpath(__FILE__) == realpath($_SERVER['SCRIPT_FILENAME']))
{
  // tell people trying to access this file directly goodbye...
  exit('This file can not be accessed directly.');
}

////////////////////////////////////////////////////////////////////////
// These are the required configuration options for the entire kiosk: //
////////////////////////////////////////////////////////////////////////

// The name of the theme to use for displaying this kiosk.
$_SESSION['system_theme'] = "console-default";

// The path to the above theme's folder relative to this file's location.
// Do not include a trailing slash.
$_SESSION['relitive_url_to_theme_folder'] = "../../theme/" . $_SESSION['system_theme'];

// The event ID this kiosk is supposed to work with.  Cannot be blank.
$_SESSION['event_id'] = "NWC37";

//The unique name of this kiosk.
$_SESSION['kiosk_id'] = $_SESSION['event_id'] . "_web_reg";

// Does this kiosk close at the pre-reg end date? [true/false]
$kiosk_closes_at_end_date = true;

// List of addresses of staff you wish internal kiosk notifications 
// to go to. (ex, "UID x has chosen to mail payment")  Format is like this:
// array("name1"=>"email1@address.com","name2"=>"email2@address.com")
$_SESSION['addresses_to_email_notifications_to'] = array(
"Registration"=>"registration@yourevent.com",
"Other Staff"=>"otherstaff@yourevent.com"
); 

// These are the name and address emails sent by this kiosk will appear to
// come from.  The address given should be a valid one and one that this 
// server is authorized to send as.  If this server does not run it's own
// mail services, be sure to either configure a local mail service that 
// forwards mail to the actual mail server for your organization, or 
// configure PHP to use your organization's SMTP server.
$_SESSION['from_name'] = "Your Even Registration System";
$_SESSION['from_address'] = "registration@yourevent.com";

// The following array defines the steps/screens that this kiosk will
// present to the user. Some steps may be skipped if the kiosk finds they
// aren't necessary.  Available steps can be found in kiosk/kiosk_screens/.
// See the documentation for rules on using these steps.
$steps = array(	"01_get_uid_v2", //Always first
				"02_ask_security_question",
				"07_set_security_question",
				"03_review_and_edit_names",
				"03_review_and_edit_all_addresses",
				"02_text_aup",
				//"04_restrict_specific_membership",
				"05_choose_membership",
				//"05_require_specific_membership",
				"06_select_freebies",
				"10_choose_badge_layout",
				//"11_user_defined_fields",
				"08_go_shopping",
				"98_online_payment"  //Must be last
);


////////////////////////////////////////////////////////////////////////////
// From here forward are the configuration settings for each of the above //
// step modules.  The settings which are optional are commented out in   //
// this example.                                                          //
////////////////////////////////////////////////////////////////////////////


////////////////////////
// Step 01_get_uid_v2 //
////////////////////////

// if set, displays a title at the top of the module screen.
$_SESSION['01_get_uid_v2']['title'] = "Welcome to Registration";

// If set, displays some text below the above title but above the prompts for
// first, last, and fan names.
$_SESSION['01_get_uid_v2']['note'] = "To start, please enter your first and last names, and your fan name (if any) below.";


///////////////////////////////////
// Step 02_ask_security_question //
///////////////////////////////////

//There are no configuration options for this kiosk step module.


///////////////////////////////////
// Step 07_set_security_question //
///////////////////////////////////

//There are no configuration options for this kiosk step module.


////////////////////////////
// Step 02_text_aup ////////
////////////////////////////
// This kiosk step module that lets you display a AUP agreement or other text
// that the user must agree to in order to continue.  Note that this can 
// can only be used once in this kiosk, so make it count.

// If set, overrides the default title with the one defined here.
$_SESSION['02_text_aup']['aup_title'] = "PLEASE NOTE!"; 

// This value determines the type of AUP shown.  Valid values are:
//      text : displays the given aup body in a (scrollable) text box
//      html : displays the given aup body as a complete web page with 
//             html formatting
// event_aup : displays the aup text configured for this event
$_SESSION['02_text_aup']['aup_type'] = "html"; // text | html | event_aup

// This is the text shown if the aup_type set above is "html" or "text".
$_SESSION['02_text_aup']['aup_body'] = "By proceeding beyond this point, you agree to abide by the <a href=\"http://www.yourevent.com/rules\" target=\"_rulestab\">Attendee Agreement or Rules</a> for Your Event attendees.<br><br>"; 

// Agree button title
$_SESSION['02_text_aup']['agree_button_text'] = "Agree and Continue";

// Disagree button title, or "" to not display this disagree button
$_SESSION['02_text_aup']['disagree_button_text'] = "Cancel Registration";

// URL to go to if they disagree, or "" to go to the main web site specified
// in the event's configuration.
$_SESSION['02_text_aup']['disagree_button_destination_url'] = "";


///////////////////////////////////
// Step 03_review_and_edit_names //
///////////////////////////////////

//There are no configuration options for this kiosk step module.


///////////////////////////////////////////
// Step 03_review_and_edit_all_addresses //
///////////////////////////////////////////
// This step module allows the user to provide contact information.
// The 'collect' option for each section specifies whether that type of
//    information should be collected.
// The 'note' option for each section is HTML that will be displayed at the
//    top of that section just under the heading.
// The 'min' option specifies the minimum number of that type of 
//    information that must be collected.
// The 'max' option specifies the maximum number of that type of
//    information that can be collected.

// Settings for collecting email addresses.
// *ALL* addresses specified here will be sent a copy of each communication
// sent by Convention Master to this user.  If you don't require at least 
// one email address, Convention Master won't be able to email the users.
$_SESSION['03_review_and_edit_all_addresses']['collect_email'] = true;
$_SESSION['03_review_and_edit_all_addresses']['email_note'] = "<span style='font-family:Arial; font-size:0.9em;'>Please provide a valid email address you check often. This will be our<br>primary method of contacting you regarding your registration.</span>";
$_SESSION['03_review_and_edit_all_addresses']['email_min'] = 1;
$_SESSION['03_review_and_edit_all_addresses']['email_max'] = 10;

// Settings for collecting mailing addresses.
$_SESSION['03_review_and_edit_all_addresses']['collect_address'] = true;
$_SESSION['03_review_and_edit_all_addresses']['address_note'] = "<span style='font-family:Arial; font-size:0.9em;'>Please provide a mailing address where you can be reached.</span>";
$_SESSION['03_review_and_edit_all_addresses']['address_min'] = 1;
$_SESSION['03_review_and_edit_all_addresses']['address_max'] = 10;
// Note, this must be exactly as listed in the list of available Countries.
$_SESSION['03_review_and_edit_all_addresses']['default_country'] = "United States";

// Settings for collecting phone numbers.
$_SESSION['03_review_and_edit_all_addresses']['collect_phone'] = true;
$_SESSION['03_review_and_edit_all_addresses']['phone_note'] = "<span style='font-family:Arial; font-size:0.9em;'>Please provide at least one telephone number where you can be reached.</span>";
$_SESSION['03_review_and_edit_all_addresses']['phone_min'] = 1;
$_SESSION['03_review_and_edit_all_addresses']['phone_max'] = 4;

// Optional privacy statement to show at the bottom of this screen.
//$_SESSION['03_review_and_edit_all_addresses']['privacy_statement'] = "<table border='0' width='75%'><tr><td align='center'><h3>Privacy Statement</h3>All information provided here is for use by this organization solely to provide more efficient service to attendees.  No information given here will be sold or traded to any third party for commercial purposes.</td></tr></table>";


//////////////////////////////////////////
// Step 04_restrict_specific_membership //
//////////////////////////////////////////

// List of membership types to prevent going past this step,
//$_SESSION['04_restrict_specific_membership']['membership_types'] = array ("BAD","DEALER");

// Large text to display at the top of error message screen.
// Defaults to "<h1> Wrong Membership type </h1>" if not defined.
//$_SESSION['04_restrict_specific_membership']['title'] = "<h1>Uh oh!</h1>";

// Message to display if the current membership type is one of the restricted
// ones.
//$_SESSION['04_restrict_specific_membership']['wrong_membership_error_message'] = "It looks like you have previously chosen a membership level that this kiosk can't handle.  Please use the correct kiosk for your membership type or contact a member of registration staff for assistance.";

// URL to send user to if they have one of the restricted membership types.
// membership_types. Defaults to Event's URL if not defined.
//$_SESSION['04_restrict_specific_membership']['startover_url'] = "http://www.yourevent.com/registration";

// Text to display on the button that sends the user to URL specifified by
// startover_url. Does not display if not defined.
//$_SESSION['04_restrict_specific_membership']['startover_button'] = "Start Over";


///////////////////////////////
// Step 05_choose_membership //
///////////////////////////////

// If set, is displayed at the top of the membership selection creen.
//$_SESSION['05_choose_membership']['note'] = "<b>Please note:</b> Choose the membership level you would like.";

// If uncommented, the list of memberships shown in 05_choose_membership will 
// be limited to ONLY those both available at the time and to this kiosk AND
// listed in this array.  If no membership types match all these restrictions,
// the user will be given an error message stating that no membership types
// are currently available.  Note that existing membership types that are
// different than these are still shown unless you also set the 
// "hide_existing_if_not_available" option below.
//$_SESSION['05_choose_membership']['limit_membership_types_to'] = array("MEMBER","SPNSR","SUPERS");

// If set to true, the kiosk will not show a member's existing membership type
// in the list if it isn't generally available at the time of listing.  BEWARE
// OF ENABLING THIS OPTION as existing members can potentially lose their
// special membership types (dealer, staff, early-bird-priced-levels, etc) 
// if forced to choose a different level to get past this membership type 
// selection.
//$_SESSION['05_choose_membership']['hide_existing_if_not_available'] = false;

// If uncommented, specifies a list of membership types which the attendee
// may not change away from without staff assistance.  Attendees with these
// membership levels are shown the other memberships available (as specified
// by configured types and above settings) but cannot choose any type but the
// one the currently have.  They are allowed to continued through the rest of
// the kiosk with that membership type.
//$_SESSION['05_choose_membership']['locked_membership_types'] = array ("LOCKED","GOOFY");

// If defined, displays this message if attendee's current mebership type
// is listed in 'locked_membership_types' above.  Defaults to "Your current
// membership type does not allow changes.".
//$_SESSION['05_choose_membership']['locked_membership_message'] = "Your current membership type does not allow changes.<br>Please <a href='http://www.yourevent.com/contact&mailTo=registration&subject=Problem%20With%20Locked%20Membership%20Type'>contact a member of registration staff</a> if you need to make changes to your membership.";

// Should this kiosk show membership types configured to appear on web kiosks?
// (Use this for public pre-registration, etc.)
$_SESSION['system_membership_types_show_web'] = true;

// Should this kiosk show membership types NOT configured to appear on web
// kiosks? (Use this for onsite or special-purpose kiosks.)
$_SESSION['system_membership_types_show_kiosk'] = false;


/////////////////////////////////////////
// Step 05_require_specific_membership //
/////////////////////////////////////////

// List of membership types to allow past this step,  If the attendee has a 
// membership type that is not in this list when they get to this step, they 
// will be given the below error message and not allowed to continue. 
//$_SESSION['05_require_specific_membership']['membership_types'] = array ("BAD","DEALER");

// Large text to display at the top of error message screen.
// Defaults to "<h1> Wrong Membership type </h1>" if not defined.
//$_SESSION['05_require_specific_membership']['title'] = "<h1>Uh oh!</h1>";

// Message to display if the current membership type isn't one of the
// required ones.
//$_SESSION['05_require_specific_membership']['wrong_membership_error_message'] = "It looks like you have chosen a membership type that can't continue with normal registration.  Please review the rules and choose a different membership type.";

// URL to send user to if they have a membership type not listed in
// membership_types. Defaults to Event's URL if not defined.
$_SESSION['05_require_specific_membership']['startover_url'] = "http://www.furryfiesta.org/registration";

// Text to display on the button that sends the user to URL specifified by
// startover_url. Does not display if not defined.
$_SESSION['05_require_specific_membership']['startover_button'] = "Start Over";


/////////////////////////////
// Step 06_select_freebies //
/////////////////////////////

//There are no configuration options for this kiosk step module.


/////////////////////////
// Step 08_go_shopping //
/////////////////////////

// If you have items that should only be sold to certain membership levels,
// specify them here.  Array key is item#, value is regex that must match 
// currently selected membership level before item will appear for purchase.
// NOTE: This temporary feature is DEPRECATED and will be removed once
//       implemented in the item definitions themselves.
//$_SESSION['08_go_shopping']['restrict_sales']['allow_by_membership'] = array(
//      '1000030' => '/^.SS/',
//      '1000000' => '/.*/',
//      '1000053' => '/THISWILLFAIL/'
//		'1000054' => '/^SUP$/'
// );

/////////////////////////////////
// Step 10_choose_badge_layout //
/////////////////////////////////
// This step module allows the user to specify which badge layout they
// want printed when they register.  Not all badge types use this.

// This variable allows you to which badge display codes you *don't* want to
// display if the user doesn't specify a fan name. (Such as Fan name only).
// This variable must be an array.
//$_SESSION['10_choose_badge_layout']['no_display_if_no_fan_name'] = array("badge_display_code");


/////////////////////////////////
// Step 11_user_defined_fields //
/////////////////////////////////
// This step module allow the user to fill in values for the user_defined_fields
// configured by an admin.
//

// This optional setting contains a list of UIDs of user_defined_fields.
// If uncommented, this setting tells the system to *only* show the specified
// user_defined_fields to the customer instead of all of them.  Note that if
// you set a dictate an answer for a field in the options below, you do not need
// to specify the UID of that question here as it will be shown automatically.
//$_SESSION['11_user_defined_fields']['show_fields'] = array("1","2","3","4");

// If uncommented, This optional setting lets you override the "description" of
// a user defined field with a question of your own written here.  You must
// duplicate this setting for each field you want to override.
//$_SESSION['11_user_defined_fields']['replace_desc']["X"] = "Question"; "replace X with the field id of the field you want to replace."

// If uncommented, this optional setting will let you dictate a specific answer
// for the field specified.  Answers that are dictated, won't show the question.
//$_SESSION['11_user_defined_fields']['dictate_answer']["X"] = "Answer";

// If uncommented, this optional setting will let you replace the title at the
// top of the 11_user_defined_fields kiosk screen with your own text.  The
// default value is "extra information" with your
//$_SESSION['11_user_defined_fields']['screen_title'] = "Title Here";


////////////////////////////
// Step 98_online_payment //
////////////////////////////
// This module handles allowing the user to submit payment either via 
// electronic or paper means.

// Email address paypal payments go to.
$_SESSION['paypal_email'] = "paypal@yourevent.com"; 

// URL to go to after a successful PayPal payemnt.
$_SESSION['success_url'] = "https://register.yourevent.com/success/"; 

// URL to go to after a failed/incomplete paypal payment.
$_SESSION['fail_url'] = "https://register.yourevent.com/fail/";

// Paypal transaction_subject.  Note that account uid gets appended to this.
// $_SESSION['paypal_item_name'] = "Payment for " . $_SESSION['event_id'] . " towards UID - "; 

// Set this true if you want to enable payment timeouts
$_SESSION['registrant_payment_holds']['enabled'] = true; 

// Treat people who don't have a payment hold as if their payment is
// "valid" = Payment hold exists and is still good
// "expired" = Payment hold has expired.
$_SESSION['registrant_payment_holds']['treat_non_existant_as'] = "valid"; 

// Payment hold durations.  
// These can either be set to a number of days or a specific date. 
// If you specify a number of days, it must NOT be surrounded by "".
// If you specify a date it must be in the format "yyyy-mm-dd".
$_SESSION['registrant_payment_holds']['payment_holds']['hold_for']['CHEQUE'] = 31;
$_SESSION['registrant_payment_holds']['payment_holds']['hold_for']['PAYPAL'] = 7;
$_SESSION['registrant_payment_holds']['payment_holds']['max_extend']['CHEQUE'] = 50;
$_SESSION['registrant_payment_holds']['payment_holds']['max_extend']['PAYPAL'] = 50;

// Set this next option to true if you don't want the 98_online_payment 
// step to send ANY email to registrants or staff.
$_SESSION['98_online_payment_main']['no_letters'] = false;

// Set this to define the currency type you can accept from PayPal.
// Examples are "USD" for US Dollars or "CAD" for Canadian Dollars.
$_SESSION['98_online_payment']['paypal_button_currency'] = "USD";

// Set this to define the text of the paper payment option button.
// If left blank or undefined it defaults to "Cheque / Money Order".
//$_SESSION['98_online_payment_main']['paper_payment_name'] = "Cashiers Check or Money Order";

// Set this to define what message is displayed when the 98_online_payment
// module completes but no payment is due (zero balance).
$_SESSION['98_online_payment_main']['no_payment_due_message'] = "You are finished, you don't need to pay anything.  We look forward to seeing you at Our Event!";

// Set this to define what message is displayed when the 98_online_payment
// module completes but there is a credit on the account (negative balance).
$_SESSION['98_online_payment_main']['credit_due_message'] = "Your account currently shows a credit.  Please <a href=\"http://www.furryfiesta.org/contact/&mailTo=registration&subject=Credit%20due\">contact us</a> to discuss this.";

/* If set, this replaces the bodies of the email sent to the registrant after
 * they choose a payment type.  Specific value names enclosed between '{{' and
 * '}}' will be replaced with current values for the registrant as given below.
 * The default value is included below as an example.
 *
 * PLEASE NOTE: The default email body changes depending on the value of 
 * $_SESSION['registrant_payment_holds']['enabled'] above.  If enabled, the
 * email contains a warning that payments sent *must* be received by 
 * {{hold_expiry}} or their membership selection will expire.  The custom
 * email body specified below DOES NOT change dependent on this value, so you
 * must write something which makes sense given your setting above.
 *
 * Substituted values include: 
 * {{event_id}} - Event ID code
 * {{uid}} - UID of registrant
 * {{pay_by}} - Method of payment ("Paypal" or "Mail-in")
 * {{hold_expiry}} - Date payment hold expires (blank if holds are disabled)
 * {{event_title}} - Name of your event as defined in event setup in console
 * {{event_url}} - URL of your event's website as defined in event setup
 * {{from_name}} - $_SESSION['from_name'] as defined above
 * {{from_address}} - $_SESSION['from_address'] as defined above
 * {{amount_owing}} - Dollar amount they currently owe (without currancy symbol)
 * {{rl_first}} - Registrant's first name
 * {{rl_last}} - Registrant's last name
 * {{fan_name}} - Registrant's furry/fan/badge name
 * {{to_name}} - If fan_name is blank this is "rl_first rl_last"
 * {{reg_num}} - Registration # for this event
 * {{current_membership_type}} - Membership type 6-character code
 * {{current_membership_name}} - Full name of membership type
 * {{address_ship_to_name}} - Name given for first mailing address
 * {{address_line_1}} - First line from first mailing address
 * {{address_line_2}} - Second line from first mailing address
 * {{address_city}} - City from first mailing address
 * {{address_state}} - State from first mailing address
 * {{address_zip}} - Zip/Postal code from first mailing address
 * {{address_country}} - Country from first mailing address
 *
*/

// To enable the setting below you need to remove both the  /* and */ 
/*
$_SESSION['98_online_payment_main']['custom_completion_email_body'] = <<<EOT
Thank you for registering for {$replacements['event_title']}.

     You have completed the online registration process for {$replacements['event_title']}, and if you have paid online you have probably already sent your payment. If, however, you have not yet sent in your payment, please be aware that the price of your membership is only held if your payment is received and processed before {$replacements['hold_expiry']}. After that date and time, prices and availability are subject to change. You will recieve a notification letter when your payment is processed by our staff. We will look forward to seeing you at our event.

      It may be prudent to make sure this email address can get through your spam filters because this email address may contact you again regarding your registration. If you marked your email address to only be contacted when needed, you will only receive information when registration staff absolutely must get in touch with you.

 Please check our website ({$replacements['event_url']}) often for more and new information!

-- Thank you again,
         Registration Computer.
EOT;
*/
?>
